# ShibbolethDjangoAuth

ShibbolethDjangoAuth is an django authentication adapter to use with a reverse
proxy handling the authentication.

## Configuration

ShibbolethDjangoAuth requires some classes to be set in configuration
parameters.


Installs the app

```
    INSTALLED_APPS = [
        'shib_auth',
    ]
```

Add the RemoteUserMiddleware. It will authenticate users when they reconnect
and calls the ``SHIBBOLETH_USER_PROVIDER`` when a new user comes.

```
    MIDDLEWARE_CLASSES = [
        'shib_auth.middleware.RemoteUserMiddleware',
    ]
```

Authentication backens will handle RemoteUserMiddleware calls when it
encounters a ``REMOTE_USER``.

```
    AUTHENTICATION_BACKENDS = [
        'shib_auth.auth_backends.ShibbolethAuthBackend',
        'shib_auth.auth_backends.ShibbolethUserCreateBackend',
    ]
```

Set the auth user model. Any model can do the trick.

```
    AUTH_USER_MODEL = 'shib_auth.User'
```

Set the User provider, the class that fetches the data from the request
and the remote user name

```
    SHIBBOLETH_USER_PROVIDER = 'shib_auth.providers.HeadersProvider'
```

By default the created users are active. This settings will set the is_active
property of users on their creation.

```
    SHIBBOLETH_USER_DEFAULT_ACTIVE = True
```

## Debug mode

The debug mode of ShibbolethDjangoAuth. It will always log you as the same
user. The login if triggered by the presence of `login` in the GET parameters.
The user is logged out when `logout` is in the GET parameters. When using
LOGIN_URL, the user is automatically logged in. The url is intercepted at the
middleware step, thus it is not required map to a view.

```
    LOGIN_URL = '/login?login'
    if DEBUG:
        MIDDLEWARE_CLASSES.insert(0, 'shib_auth.debug.DebugBatmanMiddleware')
```
