#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

from paver.easy import task, cmdopts, consume_args, needs, call_task, might_call


def init(env):
    env.defaults.TESTS_ROOT = 'shib_auth.tests'


try:
    __import__('sett')
except ImportError:
    pass


@task
@cmdopts([
    ('south', 'S', 'Use south'),
])
def django_settings(options):
    import django
    from django.conf import settings

    conf = {
        'WSGI_APPLICATION': 'shib_auth.wsgi',
        'INSTALLED_APPS': [
            'shib_auth.tests',
            'shib_auth',
            'django.contrib.auth',
            'django.contrib.contenttypes',
        ],
        'DATABASES': {
            'default': {
                'ENGINE': 'django.db.backends.sqlite3',
                'NAME': 'db',
            },
        },
        'ROOT_URLCONF': 'shib_auth.tests.urls',
        'SOUTH_MIGRATION_MODULES': {
            'shib_auth': 'shib_auth.south_migrations',
        },
    }

    if getattr(options, 'south', False):
        conf['INSTALLED_APPS'].append('south')

    settings.configure(**conf)

    if hasattr(django, 'setup'):
        django.setup()


@task
@consume_args
@needs('django_settings')
def django(args):
    call_task('sett.django.django', args=args)


@task
@might_call('sett.jenkins.jenkins')
@needs(['django_settings', 'setup_options'])
def jenkins():
    call_task('sett.jenkins.jenkins')


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'r') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'r') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    import setuptools
    from paver.setuputils import setup
    readme_md = os.path.join(os.path.dirname(__file__), 'README.md')
    with open(readme_md, 'r') as readme_file:
        readme = readme_file.read()

    setup(
        name='shib_auth',
        version=find_version('shib_auth/__init__.py'),
        description='Shibboleth authentication for django',
        long_description=readme,
        author='Grégoire ROCHER',
        author_email='gr@enix.org',
        packages=setuptools.find_packages(
            include=[
                'shib_auth',
                'shib_auth.*'
            ],
            exclude=[
                'shib_auth.tests'
            ]
        ),
        include_package_data=True,
        install_requires=parse_requirements('requirements.txt'),
        zip_safe=False,
        keywords='shib_auth',
        classifiers=[
        ],
        test_suite='tests',
    )
